@@ -5,17 +5,23 @@ class NeitherStringNorPregexException(Exception):
     '''
 
     def __init__(self):
+        '''
+        The class's constructor.
+        '''
         super().__init__("The argument that was provided is neither a string nor a subtype of \"Pregex\".")
 
 
 
-class NeitherStringNorTokenException(Exception):
+class NeitherCharNorTokenException(Exception):
     '''
-    This exception is thrown whenever an argument is neither a "Token" \
-    instance nor a string, even though it is required to be.
+    This exception is thrown whenever an argument is neither an instance \
+    belonging in module "tokens" nor a single character string.
     '''
 
     def __init__(self):
+        '''
+        The class's constructor.
+        '''
         super().__init__("At least one of the provided arguments is neither a string nor a token.")
 
 
@@ -26,6 +32,9 @@ class NonStringArgumentException(Exception):
     '''
 
     def __init__(self):
+        '''
+        The class's constructor.
+        '''
         super().__init__("The argument that was provided is not a string.")
 
 
@@ -36,9 +45,9 @@ class NegativeArgumentException(Exception):
 
     def __init__(self, n: int):
         '''
-        The class' constructor.
+        The class's constructor.
 
-        param int n: The integer because of which this exception was thrown.
+        :param int n: The integer because of which this exception was thrown.
         '''
         super().__init__(f"Argument of value \"{n}\" is less than zero.")
 
@@ -51,9 +60,9 @@ class NonPositiveArgumentException(Exception):
 
     def __init__(self, n: int):
         '''
-        The class' constructor.
+        The class's constructor.
 
-        param int n: The integer because of which this exception was thrown.
+        :param int n: The integer because of which this exception was thrown.
         '''
         super().__init__(f"Argument of value \"{n}\" is non-positive.")
 
@@ -66,10 +75,10 @@ class MinGreaterThanMaxException(Exception):
 
     def __init__(self, min: int, max: int):
         '''
-        The class' constructor.
+        The class's constructor.
 
-        param int min: The integer because of which this exception was thrown.
-        param int max: The integer because of which this exception was thrown.
+        :param int min: The integer because of which this exception was thrown.
+        :param int max: The integer because of which this exception was thrown.
         '''
         super().__init__(f"Minimum value \"{min}\" is greater than maximum value \"{max}\.")
 
@@ -81,6 +90,9 @@ class LessThanTwoArgumentsException(Exception):
     '''
 
     def __init__(self):
+        '''
+        The class's constructor.
+        '''
         super().__init__("This constructor requires at least two arguments.")
 
 
@@ -91,6 +103,11 @@ class InvalidCapturingGroupNameException(Exception):
     '''
 
     def __init__(self, name: str):
+        '''
+        The class's constructor.
+
+        :param str name: The string type argument because of which this exception was thrown.
+        '''
         super().__init__(f"Name \"{name}\" is not valid. A capturing group's " +
         "name must be an alphanumeric sequence that starts with a non-digit.")
 
@@ -102,9 +119,9 @@ class NonIntegerArgumentException(Exception):
 
     def __init__(self, arg):
         '''
-        The class' constructor.
+        The class's constructor.
 
-        param Any arg: The unknown type argument because of which this exception was thrown.
+        :param Any arg: The unknown type argument because of which this exception was thrown.
         '''
         super().__init__(f"Argument \"{arg}\" is not an integer.")
 
@@ -126,11 +143,11 @@ class CannotBeUnionedException(Exception):
 
     def __init__(self, pre1, pre2, are_both_classes: bool):
         '''
-        The class' constructor.
+        The class's constructor.
 
-        param Pregex pre1: The "Pregex" instance because of which this exception was thrown.
-        param Pregex pre2: The "Pregex" instance because of which this exception was thrown.
-        param bool are_both_classes: Indicates whether both "Pregex" instances are of type "__Class".
+        :param Pregex pre1: The "Pregex" instance because of which this exception was thrown.
+        :param Pregex pre2: The "Pregex" instance because of which this exception was thrown.
+        :param bool are_both_classes: Indicates whether both "Pregex" instances are of type "__Class".
         '''
         m = f"Classes and negated classes cannot be unioned together." if are_both_classes \
             else f"Objects of type {type(pre1)} and {type(pre2)} cannot be combined."
@@ -145,11 +162,11 @@ class CannotBeSubtractedException(Exception):
 
     def __init__(self, pre1, pre2, are_both_classes: bool):
         '''
-        The class' constructor.
+        The class's constructor.
 
-        param Pregex pre1: The "Pregex" instance because of which this exception was thrown.
-        param Pregex pre2: The "Pregex" instance because of which this exception was thrown.
-        param bool are_both_classes: Indicates whether both "Pregex" instances are of type "__Class".
+        :param Pregex pre1: The "Pregex" instance because of which this exception was thrown.
+        :param Pregex pre2: The "Pregex" instance because of which this exception was thrown.
+        :param bool are_both_classes: Indicates whether both "Pregex" instances are of type "__Class".
         '''
         m = f"Classes and negated classes cannot be subtracted from one another" if are_both_classes \
             else f"Objects of type {type(pre1)} and {type(pre2)} cannot be subtracted from one another."
@@ -164,10 +181,10 @@ class EmptyClassException(Exception):
 
     def __init__(self, pre1, pre2):
         '''
-        The class' constructor.
+        The class's constructor.
 
-        param Pregex pre1: The "Pregex" instance because of which this exception was thrown.
-        param Pregex pre2: The "Pregex" instance because of which this exception was thrown.
+        :param Pregex pre1: The "Pregex" instance because of which this exception was thrown.
+        :param Pregex pre2: The "Pregex" instance because of which this exception was thrown.
         '''
         m = f"Cannot subtract class \"{pre2}\" from class \"{pre1}\"" \
             " as this results into an empty class."
@@ -182,10 +199,10 @@ class InvalidRangeException(Exception):
 
     def __init__(self, start, end):
         '''
-        The class' constructor.
+        The class's constructor.
 
-        param int start: The integer because of which this exception was thrown.
-        param int end: The integer because of which this exception was thrown.
+        :param int start: The integer because of which this exception was thrown.
+        :param int end: The integer because of which this exception was thrown.
         '''
         super().__init__(f"\"[{start}-{end}]\" is not a valid range.")
 
@@ -193,16 +210,34 @@ class InvalidRangeException(Exception):
 class CannotBeQuantifiedException(Exception):
     '''
     This exception is thrown whenever an instance of a class \
-    that is part of the "Anchor" assertions is being quantified.
+    that is part of the "assertions" module is being quantified.
     '''
 
     def __init__(self, pre):
         '''
-        The class' constructor.
+        The class's constructor.
 
-        param __Anchor pre: The "__Anchor" instance because of which this exception was thrown.
+        :param __Assertion pre: The "__Assertion" instance because of which this exception was thrown.
         '''
         super().__init__(f"Instance of type {type(pre)} is not quantifiable.")
 
 
+class NonFixedWidthPatternException(Exception):
+    '''
+    This exception is thrown whenever an non-fixed-width pattern
+    is being provided as parameter "pre2" to either "PrecededBy"
+    or "NotPrecededBy".
+    '''
+
+    def __init__(self, lookbehind, pre):
+        '''
+        The class's constructor.
+
+        :param __Lookaround lookbehind: The "__Lookaround" instance because of which this exception was thrown.
+        :param Pregex pre: The "Pregex" instance because of which this exception was thrown.
+        '''
+        super().__init__(f"Instance of type {type(lookbehind)} cannot receive an instance of type {type(pre)} in "
+            "place of parameter \"pre2\" as the latter represents a pattern whose width is not fixed.")
+
+
 
