@@ -1,11 +1,12 @@
 import pregex.pre as _pre
-import pregex.assertions as _assertions
 import pregex.exceptions as _exceptions
 
 
 class __Quantifier(_pre.Pregex):
     '''
     Constitutes the base class for every class within "quantifiers.py".
+
+    :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
     '''
     def __init__(self, pre: _pre.Pregex or str, is_greedy: bool, transform) -> '__Quantifier':
         if issubclass(pre.__class__, _pre.Pregex) and pre._get_type() == __class__._PatternType.Assertion:
@@ -17,24 +18,28 @@ class __Quantifier(_pre.Pregex):
 
 class Optional(__Quantifier):
     '''
-    Matches the provided pattern zero or one times.
+    Matches the provided pattern once or not at all.
 
     :param Pregex | str pre: The pattern that is to be matched, provided either as a string \
         or wrapped within a "Pregex" subtype instance.
     :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
         When declared as such, the regex engine will try to match \
         the expression as many times as possible. Defaults to 'True'.
+
+    :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
     '''
 
     def __init__(self, pre: _pre.Pregex or str, is_greedy: bool = True) -> _pre.Pregex:
         '''
-        Matches the provided pattern zero or one times.
+        Matches the provided pattern once or not at all.
 
         :param Pregex | str pre: The pattern that is to be matched, provided either as a string \
             or wrapped within a "Pregex" subtype instance.
         :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
             When declared as such, the regex engine will try to match \
             the expression as many times as possible. Defaults to 'True'.
+
+        :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
         '''
         super().__init__(pre, is_greedy, lambda pre, is_greedy: pre._optional(is_greedy))
 
@@ -48,6 +53,8 @@ class Indefinite(__Quantifier):
     :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
         When declared as such, the regex engine will try to match \
         the expression as many times as possible. Defaults to 'True'.
+
+    :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
     '''
 
     def __init__(self, pre: _pre.Pregex or str, is_greedy: bool = True) -> _pre.Pregex:
@@ -59,11 +66,13 @@ class Indefinite(__Quantifier):
         :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
             When declared as such, the regex engine will try to match \
             the expression as many times as possible. Defaults to 'True'.
+
+        :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
         '''
         super().__init__(pre, is_greedy, lambda pre, is_greedy: pre._indefinite(is_greedy))
 
 
-class AtLeastOnce(__Quantifier):
+class OneOrMore(__Quantifier):
     '''
     Matches the provided pattern one or more times.
 
@@ -72,6 +81,8 @@ class AtLeastOnce(__Quantifier):
     :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
         When declared as such, the regex engine will try to match \
         the expression as many times as possible. Defaults to 'True'.
+
+    :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
     '''
 
     def __init__(self, pre: _pre.Pregex or str, is_greedy: bool = True) -> _pre.Pregex:
@@ -83,8 +94,10 @@ class AtLeastOnce(__Quantifier):
         :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
             When declared as such, the regex engine will try to match \
             the expression as many times as possible. Defaults to 'True'.
+
+        :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
         '''
-        super().__init__(pre, is_greedy, lambda pre, is_greedy: pre._at_least_once(is_greedy))
+        super().__init__(pre, is_greedy, lambda pre, is_greedy: pre._one_or_more(is_greedy))
 
 
 class Exactly(__Quantifier):
@@ -94,6 +107,10 @@ class Exactly(__Quantifier):
     :param Pregex | str pre: The pattern that is to be matched, provided either as a string \
         or wrapped within a "Pregex" subtype instance.
     :param int n: The exact number of times that the provided pattern is to be matched.
+
+    :raises NonIntegerArgumentException: Parameter 'n' is not an integer.
+    :raises NonPositiveArgumentException: Parameter 'n' is less than one.
+    :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
     '''
 
     def __init__(self, pre: _pre.Pregex or str, n: int) -> _pre.Pregex:
@@ -103,7 +120,15 @@ class Exactly(__Quantifier):
         :param Pregex | str pre: The pattern that is to be matched, provided either as a string \
             or wrapped within a "Pregex" subtype instance.
         :param int n: The exact number of times that the provided pattern is to be matched.
+
+        :raises NonIntegerArgumentException: Parameter 'n' is not an integer.
+        :raises NonPositiveArgumentException: Parameter 'n' is less than one.
+        :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
         '''
+        if not isinstance(n, int) or isinstance(n, bool):
+            raise _exceptions.NonIntegerArgumentException(n)
+        if n < 1:
+            raise _exceptions.NonPositiveArgumentException(n)
         super().__init__(pre, False, lambda pre, _: pre._exactly(n))
 
 
@@ -117,6 +142,10 @@ class AtLeast(__Quantifier):
     :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
         When declared as such, the regex engine will try to match \
         the expression as many times as possible. Defaults to 'True'.
+
+    :raises NonIntegerArgumentException: Parameter 'n' is not an integer.
+    :raises NegativeArgumentException: Parameter 'n' is less than zero.
+    :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
     '''
 
     def __init__(self, pre: _pre.Pregex or str, n: int, is_greedy: bool = True) -> _pre.Pregex:
@@ -129,7 +158,15 @@ class AtLeast(__Quantifier):
         :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
             When declared as such, the regex engine will try to match \
             the expression as many times as possible. Defaults to 'True'.
+
+        :raises NonIntegerArgumentException: Parameter 'n' is not an integer.
+        :raises NegativeArgumentException: Parameter 'n' is less than zero.
+        :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
         '''
+        if not isinstance(n, int) or isinstance(n, bool):
+            raise _exceptions.NonIntegerArgumentException(n)
+        if n < 0:
+            raise _exceptions.NegativeArgumentException(n)
         super().__init__(pre, is_greedy, lambda pre, is_greedy: pre._at_least(n, is_greedy))
 
 
@@ -143,6 +180,10 @@ class AtMost(__Quantifier):
     :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
         When declared as such, the regex engine will try to match \
         the expression as many times as possible. Defaults to 'True'.
+
+    :raises NonIntegerArgumentException: Parameter 'n' is not an integer.
+    :raises NonPositiveArgumentException: Parameter 'n' is less than one.
+    :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
     '''
 
     def __init__(self, pre: _pre.Pregex or str, n: int, is_greedy: bool = True) -> _pre.Pregex:
@@ -155,7 +196,15 @@ class AtMost(__Quantifier):
         :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
             When declared as such, the regex engine will try to match \
             the expression as many times as possible. Defaults to 'True'.
+
+        :raises NonIntegerArgumentException: Parameter 'n' is not an integer.
+        :raises NonPositiveArgumentException: Parameter 'n' is less than one.
+        :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
         '''
+        if not isinstance(n, int) or isinstance(n, bool):
+            raise _exceptions.NonIntegerArgumentException(n)
+        if n < 1:
+            raise _exceptions.NonPositiveArgumentException(n)
         super().__init__(pre, is_greedy, lambda pre, is_greedy: pre._at_most(n, is_greedy))
 
 
@@ -170,6 +219,12 @@ class AtLeastAtMost(__Quantifier):
     :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
         When declared as such, the regex engine will try to match \
         the expression as many times as possible. Defaults to 'True'.
+
+    :raises NonIntegerArgumentException: Either one of parameters 'min' or 'max' is not an integer.
+    :raises NegativeArgumentException: 'min' is less than zero.
+    :raises NonPositiveArgumentException: 'max' is less than one.
+    :raises MinGreaterThanMaxException: 'min' is greater than max.
+    :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
     '''
 
     def __init__(self, pre: _pre.Pregex or str, min: int, max: int, is_greedy: bool = True) -> _pre.Pregex:
@@ -183,5 +238,21 @@ class AtLeastAtMost(__Quantifier):
         :param bool is_greedy: Indicates whether to declare this quantifier as greedy. \
             When declared as such, the regex engine will try to match \
             the expression as many times as possible. Defaults to 'True'.
+
+        :raises NonIntegerArgumentException: Either one of parameters 'min' or 'max' is not an integer.
+        :raises NegativeArgumentException: 'min' is less than zero.
+        :raises NonPositiveArgumentException: 'max' is less than one.
+        :raises MinGreaterThanMaxException: 'min' is greater than max.
+        :raises CannotBeQuantifiedException: This class is applied to an instance that represents an "assertion" pattern.
         '''
+        if not isinstance(min, int) or isinstance(min, bool):
+            raise _exceptions.NonIntegerArgumentException(min)
+        if not isinstance(max, int) or isinstance(max, bool):
+            raise _exceptions.NonIntegerArgumentException(max)
+        if min < 0:
+            raise _exceptions.NegativeArgumentException(min)
+        elif max < 1:
+            raise _exceptions.NonPositiveArgumentException(max)
+        elif max < min:
+            raise _exceptions.MinGreaterThanMaxException(min, max)
         super().__init__(pre, is_greedy, lambda pre, is_greedy: pre._at_least_at_most(min, max, is_greedy))
\ No newline at end of file
